| new_photon | R Documentation |
Initialize a photon instance by creating a new photon object. This object is stored in the R session and can be used to perform geocoding requests.
Instances can either be local or remote. Remote instances require nothing
more than a URL that geocoding requests are sent to. Local instances require
the setup of the photon executable, a search index, and Java. See
photon_local for details.
new_photon(
path = NULL,
url = NULL,
photon_version = NULL,
region = NULL,
opensearch = TRUE,
mount = TRUE,
overwrite = FALSE,
quiet = FALSE,
country = NULL
)
path |
Path to a directory where the photon executable and data
should be stored. Defaults to a directory "photon" in the current
working directory. If |
url |
URL of a photon server to connect to. If |
photon_version |
Version of photon to be used. A list of all
releases can be found here: https://github.com/komoot/photon/releases/.
Ignored if |
region |
Character string that identifies a region or country. An
extract for this region will be downloaded. If |
opensearch |
Deprecated for photon versions >= 1.0.0 and superseded
for photon versions >= 0.7.0. If |
mount |
If |
overwrite |
If |
quiet |
If |
country |
Deprecated since photon 1.0.0. Use |
An R6 object of class photon.
# connect to public API
photon <- new_photon()
# connect to arbitrary server
photon <- new_photon(url = "https://photonserver.org")
if (has_java("11")) {
# set up a local instance in a temporary directory
dir <- file.path(tempdir(), "photon")
photon <- new_photon(dir, region = "Andorra")
photon$purge(ask = FALSE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.