| with_photon | R Documentation |
Evaluate R code with a photon instance without changing the active photon mount.
with_photon(photon, code)
photon |
An object of class |
code |
Code to execute in the temporary environment. |
The results of the evaluation of the code argument.
# Get a public instance
pub_photon <- new_photon()
# Mount a custom instance
new_photon(url = "https://localhost:8001/")
# Geocode with the public instance only once
with_photon(pub_photon, geocode("Rutland"))
# The custom instance is still mounted
get_instance()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.